Afrikaans
Akan
Albanian
Amharic
Arabic
Armenian
Azerbaijani
Basque
Belarusian
Bemba
Bengali
Bihari
Bosnian
Breton
Cambodian
Catalan
Cebuano
Cherokee
Chichewa
Chinese (Simplified)
Chinese (Traditional)
Corsican
Croatian
Czech
Danish
Dutch
English
Esperanto
Estonian
Ewe
Faroese
Filipino
Finnish
French
Frisian
Ga
Galician
Georgian
Greek
Guarani
Gujarati
Haitian Creole
Hausa
Hawaiian
Hebrew
Hindi
Hmong
Hungarian
Icelandic
Igbo
Indonesian
Interlingua
Irish
Italian
Japanese
Javanese
Kannada
Kazakh
Kinyarwanda
Kirundi
Kongo
Korean
Krio (Sierra Leone)
Kurdish
Kurdish (Soranรฎ)
Kyrgyz
Laothian
Latin
Latvian
Lingala
Lithuanian
Lozi
Luganda
Luo
Luxembourgish
Macedonian
Malagasy
Malay
Malayalam
Maltese
Maori
Marathi
Mauritian Creole
Moldavian
Mongolian
Myanmar (Burmese)
Montenegrin
Nepali
Nigerian Pidgin
Northern Sotho
Norwegian
Norwegian (Nynorsk)
Occitan
Oriya
Oromo
Pashto
Persian
Polish
Portuguese (Portugal)
Punjabi
Quechua
Romanian
Romansh
Runyakitara
Russian
Samoan
Scots Gaelic
Serbian
Serbo-Croatian
Sesotho
Setswana
Seychellois Creole
Shona
Sindhi
Sinhalese
Slovak
Slovenian
Somali
Spanish
Spanish (Latin American)
Sundanese
Swahili
Swedish
Tajik
Tamil
Tatar
Telugu
Thai
Tigrinya
Tonga
Tshiluba
Tumbuka
Turkmen
Twi
Uighur
Ukrainian
Urdu
Uzbek
Vietnamese
Welsh
Wolof
Xhosa
Yiddish
Yoruba
Zulu
โช
[indistinct chatter, laughing]
-Anything? -Nothing. DANNY: Hmm.
Twelve o'clock.
I see him.
So I told Madam Secretary everything she was doing wrong.
A week later, I'm chair of the Housing subcommittee. -[
[laughing]
-LENA: Senator. A word?
Ah. Excuse me for a second.
My apologies. I'm not sure we're acquainted, Miss... Detective,
actually. Detective Silver and Detective Reagan. DANNY: You
know, we're the cops you've been dodging for the last three days.
My assistant must have dropped the ball. Let's talk outside.
DANNY: Claire Hayes. She works here in the hotel. Disappeared
three days ago in the middle of her shift. Usually, when a woman
disappears like that, it ends with a body. How could I help
your investigation? DANNY: You're staying in the hotel.
Have you seen her, had any interactions with her? None come
to mind. There are 300 rooms. Why are you harassing me?
Because the witnesses that we spoke to said that you and
Claire got into an argument right outside the hotel bar,
just hours before she went missing. Yes, I did speak with
her. Not an argument, though. Just a casual conversation. I
was asking about some towels for my room. Towels? Wow. -[
[Danny throat clearing]
-We pulled the security footage. Now, does that look like a
casual conversation about towels to you? โช
I'm only now realizing you and I have met before. I apologize,
Detective Silver. I'd forgotten our conversation years back.
LENA: I remember it perfectly. You want to know what else I
remember, you slick son of a... Senator, we're trying to piece
together her whereabouts. I have so much respect for the BPD, the
work you do. But, we're having this conversation in a hotel
hallway, not a police station. So, assuming I'm free to go,
I'll suggest a more respectful tone going forward. Enjoy your
party while you can.
You want to tell me what's going on, Serpico? -Do you know this
guy? -Don't worry about it, Reagan. We're partners. We're
tracking a suspect who you have a history with and you didn't
bother to tell me anything about it. Yeah, I am worried about it.
What is going on? If he is involved... that woman is
already dead.
BECKY: You recently secured a huge indictment against the
Russian mob in Boston. Yes. For 20 years, those criminals have
been profiting on the backs of working people. No longer.
They're done. That Russian mob case was also mentioned in a few
excerpts from a book written by a former ADA of yours, Teddy
Bradford. Your name also comes up quite a few times. I'd love
to get your reaction. Bradford writes that you're soft on crime
and highlights what he calls prosecutorial mistakes from your
ADA days. Your response? Well, this is all news to me, so all I
can say is no comment. He's suggesting that you lack the
experience... I'm afraid we're up against a hard stop. Thank
you so much, Becky. Always great speaking with you, Becky. Keep
asking the hard questions.
[door opens]
Why didn't we know about this book? I'm willing to bet
Bradford's people leaked those chapters specifically to create
this moment. Calculated ambush. If this goes wide... Serious
journalists don't write stories around "no comment." "No
comment" is just the hook. The story is whatever that weasel
has cooked up for his book. Okay, you don't know him like I
know him. Teddy is reckless but he's not a weasel. If the
story's in the book, we just need to see it. Okay.
Charlie, set up a meeting with Teddy. I want to know what he's
planning before we do anything rash. -Done. -[
[door opens, closes]
[horns honking]
SEAN: That fantasy league has been blowing up my phone all
day. Dude, you traded Williams for Brown and you expect us not
to say anything? What's the matter with Brown? -I can't with
you. -What? You rattle off yards-per-carry stats like it's
nothing and then you trade for a dude who's 100% cooked. I'm not
gonna give up on a guy just 'cause he's going through a
rough patch, okay? Brown's gonna turn it around. This bleeding
heart thing of yours is 100% tanking your chances at the
playoffs. Oh. Eddie C. back at it again. This guy ever give up?
-Oh! Excuse me. I'm so sorry. -Hey, watch it. Hey, no, I
apologize.
-Eddie, come on, man. -No, hey, guys, look, no, thi... He stole
this from somebody else. Look. He... Guys, look at that. -It
wasn't me. Hey. -SEAN: Come on, man. -Give me the bag. Eddie.
-Hey, no, no, no! -I should go. Come on. -Don't run, Eddie.
-Don't make me run! -No, no! Be cool, man! Be cool, come on!
Hey... Oh! Okay, wow. Hey, look at that. You're... I feel like
we're getting engaged here. That's found property. Hey.
-Come on, buddy. -I-I hear what you're saying, guys. Guys, look.
-I-I... -Eddie, Eddie, you know you have the right to remain
silent, right? No. I-I-I... I get it. You know, but I-I'm just
saying. I was... It's collecting that. See, I was collecting
-all-all that stuff, so I... -Reagan? -Know what I mean?
-What's up with that suitcase?
Guys, is that anyone's bag? No? Everybody move back, okay?
Police matter. At least a hundred yards, please. -Come on,
guys. -Got a suspicious package. -Unattended suitcase. -SEAN:
Thank you. We're evacuating the park. -Yeah. -Hey, you-you're
getting evacuated? What do... What... -Copy. -When am I
getting evacuated? -JONAH: Okay, we'll keep an eye on it. -EDDIE:
Hey. -Thank you. -Hey, boss. Boss, when-when am I getting
evacuated? Silver... is that suitcase bleeding?
Yeah.
SARAH: Hey. You know you don't need a private appointment to...
Uh-oh. You have your "something's wrong" face on. How
worried should I be? Worried enough that I thought you should
hear this directly.
-Have a seat. -EDWIN: I'd like you to meet one of our Sunday
School teachers, Ava. Ava, this is my granddaughter, Sarah. -Hi.
-Hi. I'd like you to tell her what you told me.
It's my sister, Joyce.
Last weekend, me and my boyfriend had a cookout. My
sister came by, in a mood. She went up to my boyfriend, showed
him her gun, in a holster, and told him if he don't start
acting right... she's gonna kill him. Ava, that is an awful
situation. If you're looking for advice, I think you should file
an official police report right away. Your boyfriend can't file
-a regular restraint between... -Sarah? There's something else.
Something Ava isn't saying.
SARAH: Ava?
My sister is Officer Joyce Davis. A cop. BPD. Please, I-I
don't mean to cause trouble. I-I just figured I should let
someone know. Ava, you did the absolute right thing coming to
me. I will handle this the right way, while protecting you and
your boyfriend, okay?
[siren whoops]
-They say she's been dead for two days. -JONAH: That's awful.
-Good work on this, boys. -Right. -Thanks, Dad. -Thank
you, sir. McCLOSKEY: Thanks for getting here so quickly. Victim
matches the description of your missing person. Thought you two
would want to take a look.
[sighs]
One time I wish I wasn't right. Yeah.
-Got to get this guy, Danny. -We will.
โช
โช
LOWELL: Not an argument, though. Just a casual conversation.
I was asking about some towels for my room.
[echoing]: ...some towels for my room.
[clears throat]
You stare any harder, you're gonna burn a hole in that
screen. Yeah, I'm overthinking, I guess. Something about the
senator? Gonna fill me in? Come on. Tell me what happened with
you two. More than I'd like. Sarah calls him -my white whale.
-The one -that got away. -Yeah, back when I first made
detective, I caught this case. It was the murder of a young sex
worker in a penthouse downtown. Nicole Anders. -Lowell was the
killer. -If he was the killer, how come he's out walking
around, you know, senator-ing? 'Cause I was green. There was
all this political pressure and warrant delays. By the time I
got the go-ahead, he had returned to the scene and
covered his tracks. -So you couldn't bring a case? -No. I'm
sure that stung. It did, and it especially stings now. You know,
it took me years to stop second-guessing myself. And to
rebuild my credibility. But I've been watching Lowell ever since
then. And he has this tell when he's lying. Watch his hand.
-Huh. -Yeah, it's a tic. And he did it at the hotel last night.
When he lied to us. I know he killed Claire, Danny. Okay. But
guys like him are slick. You know, they get off on
technicalities. You want to get him, you got to build a case
that is airtight -Mm-hmm. -and follow all of the evidence. Of
course. Speaking of, I pulled these from different
surveillance cameras, but all with the same time stamp. Look
at this guy. His movement, his posture. It's like he's pulling
something inside that suitcase. LENA: He's coming from the
direction of the hotel where Lowell is staying. Build matches
Lowell. Height is right, too. Yep. Could be him. But we're
gonna need a lot more than "could be" to nail a state
senator. We're gonna have to dot the T's. The I's. And that's
usually what I do. Picking up your habits. Yeah, I'm picking
up some of yours, too. -[
[keys jingle]
-Let's roll. SARAH: As superintendent, my days are
busy. Today, I spent my morning learning about the incident at
the cookout last week. You threatened your sister's
boyfriend, Carl, with your service weapon. And worse, you
said that, as a cop, you could, quote, "Get away with an awful
lot," unquote. So, tell me, Officer, what's going on?
Superintendent, ma'am, that's all just, you know, "he said,
she said." Hearsay. I mean, it didn't go down like that at all.
I was kind of hoping you'd be straight with me, Officer. Don't
think I didn't do my homework. I've gone through your file.
Questioned witnesses, your fellow officers. And the staff
at the hospital where you shoved Carl last June. With your
disciplinary record, you're looking at suspension, if not
termination. So, BS time is over. I will ask you again.
-What is going on? -Ma'am.
My sister's boyfriend Carl hits her. Has been for a year. Now, I
don't like that I did what I did, but Ava's my baby sister.
You're a cop. If your sister's being abused, -you go through
the proper channels. -Ma'am, with respect, the proper
channels aren't working. Ava's too scared of Carl to admit what
he's doing.
When we were young, I swore to Ava I would do anything to keep
her safe.
And that's what I'm going to do.
Officer Davis, your actions are unbecoming of a Boston Police
officer. Two weeks suspension without pay. Leave your ID and
badge here. Your sergeant will take your weapon and give it
back to you at the end of your hit. Dismissed.
[door opens, closes]
I was surprised you reached out so quickly, Mae. I was expecting
some sort of riposte. Thank you.
Teddy, what are you doing? I wrote a book. That's a crime in
Boston now? That's not what I'm talking about.
The book, the released excerpts, this whole persona-- this isn't
who you are. No, you're thinking of who I was. I've evolved. By
necessity. After you forced me out of the D.A.'s office. You
coached a witness. I offered you a demotion. You chose to leave.
When I'm D.A., you'll be seen as shortsighted. Jealous. But we'd
both know that's not the truth. Mae. God, I feel badly for you.
Still playing yesterday's game. Yesterday's game? "But we both
know that's not the truth." You really think that matters more
than the narrative?
[scoffs]
How typically Mae Silver.
[chuckles]
When you're D.A. Who's getting you to think like this, huh?
Daddy's friends? Spare me the condescension.
Teddy, let me give you a little bit of advice.
Don't underestimate me.
-SEAN: Okay, ready for this one? -JONAH: Yeah, thanks. You know
this is the second time this month that we've processed
Eddie's haul. -He's a crook. But still, you got to admire -[
[dog barking]
-the man's dedication. -DOHERTY: All right, all right. I'm
coming. -[
[whining]
-What is it, girl? Dog's alerting on the toy, boys. SEAN:
What do we got here?
-[
[whistles]
-DOHERTY: Drugs with that seal are all over, south of Mass Ave.
-What's the story with this stuff? -DOHERTY: Drug Control
hit the dealers working the parks. We scared 'em. So they
switched up how they're moving product using cute little games
like this. If we could track down where this one came from,
would that -help you guys out at all? -DOHERTY: Sure. If you get
lucky, you spot something, we'd for sure want to know.
I know what that look. How are we even supposed to track these
things down? Eddie is a pickpocket, he's not the dealer.
We ask him where he lifted it. Except he just got out on bail.
Then we go find him. Unless you'd rather sit around here
filling out paperwork. Your choice.
Claire was the sweetest girl. She had all these dreams. But
she was an amazing photographer. She went to school to be a
photojournalist. Boston was supposed to be her fresh start.
We went through the security footage from the other night.
Her interaction with Senator Lowell. Yeah, people like Claire
don't usually get caught up with a state senator for no reason.
Any idea what might have set him off? No, I don't know. Claire
was patient, easygoing. Senator Lowell-- he can be very
difficult. This is the stuff that Claire left in her locker
and the hotel computer records you asked for. I just hope you
can figure out what happened.
We are gonna do our absolute best.
Thank you.
MAE
[on recording]: All I can say is no comment.
[door opens, closes]
What's going on, Charlie? Someone edited your podcast
exit. Made it look like you stormed out. "#What Is D.A.
Silver Hiding?" is trending. What are you talking about? What
I'm talking about is 17,000 mentions in the last hour. Teddy
did this. Like I said: weasel. No co-co-co-co-comment.
Just had coffee with him ten minutes ago.
Pull the Blackburn Group file.
I remember you telling me you wouldn't ever... I said I would
tell you when. Pull the file. -[
[typing]
-LENA: Ooh! Perfect. Got the hotel's key card logs. Now we
can tell where the senator's been. Are we checking all of the
key card records or just the senator's?
He accessed the public service elevator 30 minutes after we saw
him at his gala. Maybe he had to go to the bathroom after eating
-those nasty crab puffs. -Ha, ha. Or maybe he went to go move
the body. -Mm. -The timeline supports it. Haven't you heard
time plus access equals opportunity? It's a theory. A
circumstantial one, but a theory. I get it. I'm a dog with
a bone. I hate to say it, it's kind of like watching myself at
work. Oh, well, then you'll develop a tolerance, won't you?
-Hope so. -Wait. Room service records show that Lowell ordered
meals for two throughout his entire stay. Including a
"Lover's Delight" package. -Champagne and caviar. -That's
very romantic. Especially considering Lowell's wife was
back home in Worcester the entire time. Maybe Lowell was
stepping out with Claire. That would be motive. Though it's
speculation, -not enough for a conviction. -Danny, I will say
it again: -Lowell killed Claire. -I get it. But we have to cover
every... piece.
Like this. Dates, times, and a number. 705. -Hmm. Room number
at the hotel? -That's what I'm thinking. Maybe Claire was
tracking somebody's movements in that room, like a slimy senator?
705.
[clicks tongue]
Name's been scrubbed from the system. -Powerful senator could
do that. -Yeah, but Lowell was staying -on six. -That's only
one floor down. Maybe he had a second room for nefarious
activities. Come on, it's a lead. We got to track it.
Haven't you heard? Showing your work closes cases. Fine. We'll
go to the seventh floor.
But wipe that smile off your face. You're way too pleased
with yourself, Reagan.
I spoke to Ava. She mentioned her sister's suspension. -How
you holding up with that? -You know, if you wanted an excuse to
check in on me, you didn't have to drive all the way out to
Somerville. We got sandwiches downstairs. The cafรฉ here
doesn't serve a real spuckie. -Mm. -You know, as the boss, I'd
think you'd be in position to rectify that. I've learned that
my command authority does not extend to the cafeteria menu.
You seem a hundred miles away. You want to talk about it? When
I was in college, I had this friend, Kelly.
Her boyfriend was obsessive, controlling. And over the course
of the year, he just turned her into a shell. I wanted so badly
to help her. I'm feeling just as powerless now as I did back
then.
Early in my ministry, I had a... a parishioner who was deeply
addicted to pain pills. I was failing him. Felt like I was
failing myself. But then one day, I sat with him on a pew and
something changed. I... I just set aside being the reverend and
I just sat there with him, -as Edwin. -And that helped him? It
helped me. I realized that God never called me to perform
miracles. He called me to show up. Your father-- he taught me
about something called Tikkun Olam. Our creator calls us to
heal the world. But He does not need us to be superheroes,
Sarah. He needs us to do what we can, as the human beings He
created us to be.
[short chuckle]
I mean, what else are we supposed to do?
EDDIE: So, you know, when you guys picked me up, I was just
waiting for-for Ducky. You guys know Ducky? Ducky? You guys know
Ducky, right? Ducky-Ducky's Pawn Shop? You know, anyways, I was
talking to him about the potential resale value of some
used speakers I may have come into contact with 'cause my
sister's girlfriend-- you know, she's a-she's a lesbian now, you
know... -[
[window shuts]
-[
[Eddie continues indistinctly]
I can't believe I let you talk me into this. This dude is never
gonna be helpful to us. -Ever. -Oh, come on. -[
[speaking indistinctly]
-Maybe this is Eddie's big moment, you know? It's his, uh,
his shot to turn things around. We-we know, with the-with the...
with the-the dagger and the-and the rings on the cover? Right
now. You get 200 bucks. As a businessman, I'm thinking to
myself, you know, -"Who am I to judge?" -[
[knocking]
Eddie. Remember why you're here. You're supposed to be leading us
to where you lifted the leprechaun doll, right? I know,
I know. Uh... you know what, guys, I'm gonna be honest with
you, it's-it's -just kind of hard to say. -JONAH: Eddie.
-Focus. -Wait, wait, wait. Uh... Wait. Okay, no, I remember, I
re-I remember, I remember. I was-I was on Wash, south of the
Arborway. You know, where all the-all the Indian restaurants
are at, where you get the vindaloo? Probably where I found
that item. That's pretty far from where we picked you up. I-I
do cover a lot of ground. That's true. It's all right, Eddie.
We'll check it out. That's not too far. Hey. You guys take
probiotics?
[elevator dings]
Got to quite figure why our victim was so fixated on that
room, 705. But then you're not even thinking about that because
you're fixated on your white whale, Senator Lowell. M.E. said
that Claire died Monday night, right after Lowell confronted
her. -Uh-huh. -And then the body was moved just hours after we
saw him at the gala. Yeah. But moved from where? We don't have
a crime scene. Not yet. That only proves he could have done
it. Doesn't prove he did. This is it. 705.
Somebody's hungry.
LENA: Yeah. Whoever's watching.
-[
[door opens]
-Hey, hey. Stop right there. Don't knock on that door. -Who
the hell are you? -Investigator Williamson, with the D.A.'s
office. I'm Detective Reagan, this is Detective Silver. We're
investigating a homicide. Why can't we knock on the door?
-Lena Silver, right? -Yes. Does your mother know you're up here?
Does she need to know we're up here? Who do you have guarded in
there?
[sighs]
Look... because you're you. The guy in there is Evgeny Leskov.
The Russian hit man? -Who? -LENA: He's an enforcer with the
Russian mob. Car bombings and executions. He's the kind of
killer that other killers cross the street to avoid. That's who
our vic was obsessed with? No wonder 705 was scrubbed from the
hotel records. -We definitely need to speak to him.
-WILLIAMSON: Anything to do with that guy needs to be cleared by
the D.A. Great. We'll clear it with the D.A. Tell my mom we're
on the way.
I understand that. No, see, I had a very crowded morning. You
know? Uh, I started over at the bus stop and then I m... I made
my way over to the doughnut crowd. You know how distracted a
man gets when-when he's eat... -when he's eating a cruller?
-Eddie, Eddie. Tell us where you found the guy who you lifted
-the toy with the drugs. -Yeah... Right, right, right, -I
know. The little... -Okay? little leprechaun toy, I know.
I-I know what you're talking about. Yeah. Very cute... cute
toy. Listen, guys, I have to... I have to go in here for a
second. I got to duck in here, got to talk to a guy about
something. -Eddie, you can't... -Look, just gimme, like, two
minutes. I see you, I get it, okay?
Paulie. Paulie! Hey, hey, hey! Okay, okay, listen, listen. Hey,
okay. Hey, uh, uh, okay. Paulie, hey... PAULIE: How dare show
your face -around here without my money, Eddie? -Paulie...
[grunts]
Help! Police! -I'm being attacked! -Get his arm! Get his
arm!
[grunting]
Oh! -Hey! -EDDIE: Whoa! Whoa, whoa! Hey, hey! -Well, now we
got to arrest you. -Hey, look, Paulie, I'm really sorry about
this. By the time you get out, I swear to God, you and me, we're
gonna be square, okay? -You better... -Great. He used us.
How's that bleeding heart now?
[Eddie groaning]
Walk. Come on. Is it bad? Feels bad.
-Come on, Eddie. -[
[groans]
CHARLIE: Hmm. Blackburn file. Worse than I remember. -Yeah,
nothing if not thorough. -Hm. These photos could not only
derail Teddy's political career, they could upend his life. Well,
this viral moment isn't dying down until the next one shows
up. D.A. Silver. Charlie. -CHARLIE: Detective. -MAE: What
are you two doing poking around my cooperating witness? We're
looking for a murderer. -Well, it's not Leskov. -DANNY: How do
you know? Because he's helping me dismantle the Russian mob in
Boston. Yeah, he's a very bad guy, he's gonna go to jail for a
very long time. However, right now he's under 24-hour
surveillance, he's got armed guards and an ankle monitor.
-So, in other words... -Airtight alibi -for Claire's murder.
-Yeah. Airtight as can be.
Sarah, do you think two weeks suspension is enough? She
threatened a civilian. Well, she was looking out for her family.
I mean, that counts for an awful lot to me. Yeah, but does that
suddenly trump her badge? Well, she kept her weapon holstered.
But the threat was real enough. So, what, she's supposed to just
stand there -while her sister gets beat up? -MAE: That's not
the point. You're police officers. Your duty is to the
law. I know. I'm just saying. Someone threatens one of my
sisters? They best watch out.
Protecting family and upholding your duty are both sacred
values. Each incomplete without the other. And to be honest,
your sisters would probably be fine. They're both armed and
very dangerous.
[laughing]
-That's right. -That's right. What are you so fascinated by?
It's Mae. Some of these jerks online are out of control.
DANNY: No phones, Sean.
Speaking of people who should watch out. SARAH: The whole
thing is so gross. The way they edited that video -is completely
manipulative. -MAE: Spent years building a reputation, and some
smug ex-employee tries to tear it down in one day.
Victims calling my office-- they must be wondering if they can
trust me to get them justice. DANNY: I never really got used
to knuckleheads taking shots at my dad in the press or online,
but the good ones see you for the good that you're doing. I
couldn't agree more. I agree too, but online, truth is just
the opening bid. Whoever's loudest is the one that gets the
attention. Yeah, but Danny's right. It's the good you do
-that's most important. -EDWIN: Amen.
The rest is just noise.
[short chuckle]
-EDWIN: Hey, good night. -MAE: Good night, boys. DANNY: You
barely said a word at dinner.
Yeah. Just... thinking, I guess. Just thinking? Come on. Tell me
what's going on.
Some guy-- a pickpocket-- used me today, and just made me
feel... like an idiot in front of Jonah. I get it. I've been
there before, believe it or not. It's easy to be jaded. What's
difficult is believing in people when they don't always believe
in themselves.
Well, how do you keep believing without being a sucker?
-Because... -What's that saying? Um, "Trust, but verify." Having
faith in people isn't naรฏve. It's what makes you a good cop.
-Uh, "Trust, but verify," huh? -Yeah. Your heart's in the right
place. Don't let one doofus change that. Come on.
LENA: I should have known this would happen. -DANNY: What? -Oh,
what always happens. People like Lowell-- they always win. I
don't know what else to do. Okay, what happened last time is
irrelevant. Why don't you have my back with this case? What are
you talking about? You've been questioning every instinct that
I have. Why don't you trust me? I need your help, Danny. And I
thought you were the kind of partner who would understand and
who would stand with me. -Was I wrong about you? -Of course I
trust you. And more importantly, I believe in you. You think I'd
be in this city if I didn't? Sean or no Sean, I would be out
of here.
And I also happen to believe that you are 100% correct about
Senator Lowell. But I've been down this road before, many
times. We have to be smarter than him. So when we nail that
son of a bitch, we nail him for good. That's what the victims
deserve. And maybe you could trust me a little bit, too.
Danny. Yeah? That call Claire made to Main Channel
Construction. -They didn't know her. -She knew them. Look. 2501
Banning Ave. That's right next door to the hotel.
This could be the same type of plastic Claire was wrapped in.
Yeah.
That is a whole lot of blood. I think we just found our crime
scene.
Yeah.
[sighs]
Hey, man, I, uh... I wanted to say sorry about how things went
down yesterday. Yeah, well, that's what you get for trusting
crooks. I don't know. Would you be mad if I said I wasn't ready
to give up my bleeding heart? ...breast pocket wallet, you
know, is very... -Okay! Uh... Oh. -OFFICER: Good? Oh! Hey,
fellas! Fellas. Listen, hey, look, those... Tho-Those were
the fellas I was telling you about. Look, I got a hot lead
for you. -Okay? I got a hot-I got a hot lead. -You two know
him? -Unfortunately. -What'd he do this time? Got him for
jumping a turnstile. Yeah, yeah... yes, yes, but I only
jumped the turnstile because I was chasing that leprechaun guy
for you. Eddie, how are we supposed to trust you, man?
Yesterday you used us to buy time for your debt. Yeah, I-I
know, I-I did, I did. I feel really bad about that, okay? But
this time I'm 100% on the level. I saw Mr. Leprechaun Guy selling
out of that park with the fountain, you know, by the-by
the old T station. -Hamill Park? -Ah. Yes. Yes. SEAN: That's
actually pretty close to where we were on our wild-goose chase
yesterday. JONAH: And the DCU officer did say the drug dealers
were working the parks. Guys, I-I saw him. Okay? I saw him. I
can ID him for you, I swear. -You book him yet? -Mm-mmm. No.
All right, Eddie. -You can show us, okay? -Yeah! But you're
staying in those cuffs. You do exactly what we say or else
you're coming right back here. Understood? -You're right, yeah,
of course, yeah. -JONAH: Sean, sounds quite familiar. Eh, come
on, live a little. He flakes again, I'll buy you a beer. Uh,
you already owe me a beer. That'll be two beers. -[
[chuckles]
-This is true. I love beers. Listen... I'm not a part of
this. I'm sorry. DISPATCH: All units, Priority 1. Off-duty
Officer Davis responding to hostage situation in progress,
requesting response. Yankee-Charlie-3 to dispatch,
take me off to that location as well.
[police radio chatter]
DAVIS: Carl! Ava? -Carl! -[
[Carl shouting]
DAVIS: Carl! Ava! Carl! Oh, my God! What's going on, Sergeant?
Superintendent. We've got boyfriend intoxicated,
barricaded inside with girlfriend, he's armed. Officer
Davis was off duty, came over, -situation deteriorated. -Carl!
Let my sister go, Carl! I have the girlfriend's cell. Hold
position and maintain perimeter until I make contact. Get Davis
back here. Officer Davis! Get back here. Why?! Don't you know
I love you?! Tell your sister to leave us alone! Carl, please.
CARL: I love you! OFFICER: Stay back, stay back.
[phone vibrates]
-What do you want? -SARAH: Carl? I'm Sarah, with Boston PD.
Sounds like you're going through something -really tough right
now. -I'm not gonna hurt her. I take care of her. I can hear
that in your voice, Carl.
You love her. But I can also tell that you are pissed off
about something. So, Carl, tell me... what has got you so pissed
off? It's Ava's cop sister. She's always in our business.
[scoffs]
If I were in your shoes, I'd feel like I was under attack.
Here you are just trying to protect -what you have with Ava.
-Exactly.-Everybody thinks I'm some kind of a monster. -What if
this could endwith both of you walking away safe? Show
everybody you are the guy who protects her.
That starts with putting that gun down and coming outside.
-Can you do...-[
[hangs up]
-Carl? -[
[disconnect tone]
OFFICER: Hands where I can see 'em! OFFICER 2: Hands up! Drop
your weapon right now! Drop it!
Weapon down. Go, go, go! OFFICER: Hold your fire! Hold
your fire!
OFFICER 3: Stay back, stay back. Joy.
It's okay. It's okay.
CSRU got fibers, prints and blood from two people. But what
was Claire doing in here? Well, we know she wanted a photo of
Leskov. She was an aspiring photojournalist, right? My money
says she set up shop here to get a photo of Leskov here. One of
those must be room 705. Yeah. Well, he put her in the suitcase
here after he dragged her...
...from this point, where he hit her. With the rebar. That was
the killing blow. But then the fight started... here.
Why? That's the question.
Wait a minute.
Oh...
Thank you, Claire.
[exhales]
It's a camera. So she must have stashed it right before he
arrived.
Time stamp says four days ago. That's just before the time of
Claire's death.
Yeah.
[short chuckle]
Definitely took these from here. And she got her photo of Leskov.
And that's not all she got. No, it isn't. Senator Lowell with
his mistress. And look-- when he saw her taking the photo. DANNY:
He didn't look too happy. Wow. He comes over here to get rid of
that photo, confronts Claire. Lowell. Blood. Crime scene. You
know what this means, right?
We got him.
EDDIE: Guys, I really love parks. It's positive vibes, good
energy. Makes it very easy for me to do my job, -if I'm being
honest, you know? -Eddie, Eddie. You're not -our C.I., okay?
Don't confess crimes to us. -Yeah, yeah, no, I know. Right.
If I wanted to, I mean, I could tell you, you know?
[chuckles]
-But I'm not gonna. -Yo, Eddie, Eddie, Eddie.
Is this the guy you were chasing? Oh, my G... Yeah, no,
no, yeah, no, that's him. I... To be honest with you, I didn't
actually expect him to be here, but yeah, yeah, that's him.
Okay, so now what do we do? I mean, do we just trust Eddie? -[
[chuckles]
-I don't trust Eddie as far as I can throw him, but... -Same.
-maybe? Don't we need, like, probable cause or something? -Do
we just... -What are you... -what are you guys talking
about? That's him. -Eddie, Eddie, -Come on, guys, get him,
-we got it. Just... Shh! -Eddie, chill, -he's right there. Hey,
hey, -Eddie, shh. -chill, chill, chill. fella! Hey! These-these
cops-- they think you're holding! Huh?
-Huh? Yeah! Yeah, see? -Go, go, go. -Probable cause! -Come on!
Hey, get him! Hey! Hey! -Run, Eddie! -Go! I'm coming! -Come
on! Come on! -Nothing to see here! Police business!
Suspect on the boardwalk.
Hey! Stop! BPD!
[grunting]
We did it! We got him! Huh? Yeah, Eddie, we did. EDDIE: Hey,
buddy. Looked like that hurt, huh?
-Man, I told you! Whoo! -Maybe that bleeding heart of yours can
actually be useful sometimes.
Tough day today? Everyone's alive.
Other than that, Tikkun Olam. I just got to keep showing up.
What else are we supposed to do?
MAE: Hello, Teddy.
[exhales]
This place seems smaller. My advisors said this meeting was
either a surrender or an attack. I said Mae Silver never
surrenders.
I'm guessing that's the attack. The opposition researchers--
they... they found quite a bit of stuff on you. -Political
blackmail. -I wanted to ambush you. Put you in your place. Give
you your own viral moment.
I'm not gonna do it. You're, what, giving up?
-What am I missing? -The bigger picture. You're young, you're
ambitious, you're very talented. You really could be someone who
makes a difference, but instead you're throwing it away for your
15 minutes of attention.
You think I'm throwing my career away? I think you're on the
verge of discovering that the people who are using you are
fair-weather friends and they're just gonna toss you aside when
it suits them. So, go on your book tour.
Just say what you want to say about me. And if you ever
remember why you wanted to become a prosecutor, then we can
talk. But Teddy, the next time you try to destroy someone's
reputation, just make sure your own house is clean first.
Because if I found this...
...imagine what your new friends will find.
JENKINS: Detectives, please. The senator's a busy man. -What are
we doing here? -DANNY: We won't waste too much of your time.
Just need to ask you a question. Fine, let's get this over with.
LENA: Our victim. Claire Hayes. An aspiring photojournalist.
Here are some photos that she took from the hotel. Is this a
photo show? DANNY: Now, we can't prove that you were yelling at
Claire because she took these photos, nor can we speak to your
state of mind in this photo of you and your lovely mistress.
-Okay, I think we're done here. -No, we're not. LENA: 'Cause,
you see, thankfully, we don't need to prove any of those
things. 'Cause we've got your hair at the scene. And your DNA
on the rebar you struck her with to kill her. DANNY: We'll also
make sure the jury gets a look at the surveillance footage of
you dragging Claire's body into the park in a suitcase, where
you were gonna dump her in the pond until you saw two officers
and panicked and then left her there to rot. But, honestly,
after seeing all this, they won't need to see that. Please.
None of this sticks.
[clears throat]
If you're so confident in your case, why even drag me down
here? LENA: So I could ask you one question. How does it feel
to know that, after all this time, escaping justice... you
are finally going away for good?
You were right and you stuck to it. I hope this finally brings
you some peace.
I get to tell Claire's family. And I get to call Mrs. Anders
tonight, tell her I finally got the guy who killed her daughter.
Yeah. Listen, Danny, you know what it meant to me to catch
this guy.
Got me off my game.
I am sorry for how I came at you. What I said about you not
having my back-- it was wrong. Honestly, I don't even know why
I took it that far. But I truly appreciate you for not taking it
to heart.
You know, I'd be lying if I said I haven't done the same thing
dozens of times in my career.
But I've been blessed with great partners. They gave me space and
grace. Allowed me to blow up.
Were still there for me, keep me on the right track. Kind of like
you did. From the moment I stepped into this city. So,
thank you.
Thank you for not bailing on me.
I don't plan on it, partner.
[chuckles softly]
Captioning sponsored by CBS and TOYOTA.Captioned byMedia
Access Group at WGBH access.wgbh.org
Can't find what you're looking for?
Get subtitles in any language from opensubtitles.com, and translate them here.